# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15protobuf/server.proto\x12\x06Server\"\xc2\x04\n\rServerCommand\x12\x0c\n\x04UUID\x18\x01 \x01(\t\x12\x15\n\x0blog_message\x18\x02 \x01(\tH\x00\x12\x18\n\x0e\x63\x61pture_screen\x18\x03 \x01(\x08H\x00\x12\x33\n\x12\x61\x64\x64_custom_control\x18\x04 \x01(\x0b\x32\x15.Server.CustomControlH\x00\x12\'\n\nset_camera\x18\x05 \x01(\x0b\x32\x11.Server.SetCameraH\x00\x12\'\n\nadd_object\x18\x06 \x01(\x0b\x32\x11.Server.AddObjectH\x00\x12;\n\x15set_key_event_handler\x18\x07 \x01(\x0b\x32\x1a.Server.SetKeyEventHandlerH\x00\x12-\n\rremove_object\x18\x08 \x01(\x0b\x32\x14.Server.RemoveObjectH\x00\x12<\n\x15remove_custom_control\x18\t \x01(\x0b\x32\x1b.Server.RemoveCustomControlH\x00\x12\x36\n\x12set_custom_control\x18\n \x01(\x0b\x32\x18.Server.SetCustomControlH\x00\x12\x14\n\nset_enable\x18\x0b \x01(\x08H\x00\x12\x1a\n\x10get_camera_state\x18\x0c \x01(\x08H\x00\x12L\n\x1eset_camera_state_event_handler\x18\r \x01(\x0b\x32\".Server.SetCameraStateEventHandlerH\x00\x42\t\n\x07\x43ommand\"\xbf\x06\n\rCustomControl\x12.\n\x06slider\x18\x01 \x01(\x0b\x32\x1c.Server.CustomControl.SliderH\x00\x12\x32\n\x08\x63heckbox\x18\x02 \x01(\x0b\x32\x1e.Server.CustomControl.CheckBoxH\x00\x12\x30\n\x07textbox\x18\x03 \x01(\x0b\x32\x1d.Server.CustomControl.TextBoxH\x00\x12\x34\n\tselectbox\x18\x04 \x01(\x0b\x32\x1f.Server.CustomControl.SelectBoxH\x00\x12.\n\x06\x62utton\x18\x05 \x01(\x0b\x32\x1c.Server.CustomControl.ButtonH\x00\x12\x39\n\x0c\x63olor_picker\x18\x06 \x01(\x0b\x32!.Server.CustomControl.ColorPickerH\x00\x12.\n\x06\x66older\x18\x07 \x01(\x0b\x32\x1c.Server.CustomControl.FolderH\x00\x1a\x62\n\x06Slider\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03min\x18\x02 \x01(\x02\x12\x0b\n\x03max\x18\x03 \x01(\x02\x12\x0c\n\x04step\x18\x04 \x01(\x02\x12\x12\n\ninit_value\x18\x05 \x01(\x02\x12\x0e\n\x06parent\x18\x06 \x01(\t\x1a<\n\x08\x43heckBox\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ninit_value\x18\x02 \x01(\x08\x12\x0e\n\x06parent\x18\x03 \x01(\t\x1a;\n\x07TextBox\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ninit_value\x18\x02 \x01(\t\x12\x0e\n\x06parent\x18\x03 \x01(\t\x1aL\n\tSelectBox\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05items\x18\x02 \x03(\t\x12\x12\n\ninit_value\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x1a&\n\x06\x42utton\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06parent\x18\x02 \x01(\t\x1a?\n\x0b\x43olorPicker\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ninit_value\x18\x02 \x01(\t\x12\x0e\n\x06parent\x18\x03 \x01(\t\x1a&\n\x06\x46older\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06parent\x18\x02 \x01(\tB\t\n\x07\x43ontrol\"A\n\x13RemoveCustomControl\x12\r\n\x03\x61ll\x18\x01 \x01(\x08H\x00\x12\x11\n\x07\x62y_uuid\x18\x02 \x01(\tH\x00\x42\x08\n\x06Object\"\xef\x02\n\tSetCamera\x12\x19\n\x0fperspective_fov\x18\x01 \x01(\x02H\x00\x12%\n\x1borthographic_frustum_height\x18\x02 \x01(\x02H\x00\x12#\n\x08position\x18\x03 \x01(\x0b\x32\x0f.Server.VecXYZfH\x00\x12!\n\x06target\x18\x04 \x01(\x0b\x32\x0f.Server.VecXYZfH\x00\x12&\n\x04roll\x18\x05 \x01(\x0b\x32\x16.Server.SetCamera.RollH\x00\x12\x13\n\troll_lock\x18\x06 \x01(\x08H\x00\x12,\n\x04mode\x18\x07 \x01(\x0e\x32\x1c.Server.SetCamera.CameraModeH\x00\x1a\x32\n\x04Roll\x12\r\n\x05\x61ngle\x18\x01 \x01(\x02\x12\x1b\n\x02up\x18\x02 \x01(\x0b\x32\x0f.Server.VecXYZf\"/\n\nCameraMode\x12\x0f\n\x0bPERSPECTIVE\x10\x00\x12\x10\n\x0cORTHOGRAPHIC\x10\x01\x42\x08\n\x06\x43\x61mera\"\xfb\x07\n\tAddObject\x12-\n\x08line_set\x18\x01 \x01(\x0b\x32\x19.Server.AddObject.LineSetH\x00\x12\x33\n\x0bpoint_cloud\x18\x02 \x01(\x0b\x32\x1c.Server.AddObject.PointCloudH\x00\x12,\n\x07overlay\x18\x03 \x01(\x0b\x32\x19.Server.AddObject.OverlayH\x00\x12&\n\x04mesh\x18\x04 \x01(\x0b\x32\x16.Server.AddObject.MeshH\x00\x12(\n\x05image\x18\x05 \x01(\x0b\x32\x17.Server.AddObject.ImageH\x00\x1a\x81\x01\n\x07LineSet\x12\x1f\n\x06points\x18\x01 \x03(\x0b\x32\x0f.Server.VecXYZf\x12\x12\n\nfrom_index\x18\x02 \x03(\x05\x12\x10\n\x08to_index\x18\x03 \x03(\x05\x12\x1f\n\x06\x63olors\x18\x04 \x03(\x0b\x32\x0f.Server.VecRGBf\x12\x0e\n\x06widths\x18\x05 \x03(\x02\x1a\x32\n\nPointCloud\x12\x10\n\x08pcd_data\x18\x01 \x01(\x0c\x12\x12\n\npoint_size\x18\x02 \x01(\x02\x1a\x97\x02\n\x07Overlay\x12!\n\x08position\x18\x01 \x01(\x0b\x32\x0f.Server.VecXYZf\x12\x0e\n\x04html\x18\x02 \x01(\tH\x00\x12\x30\n\x05image\x18\x03 \x01(\x0b\x32\x1f.Server.AddObject.Overlay.ImageH\x00\x12\x36\n\x04type\x18\x04 \x01(\x0e\x32(.Server.AddObject.Overlay.CoordinateType\x1a$\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05width\x18\x02 \x01(\x05\"=\n\x0e\x43oordinateType\x12\x14\n\x10WORLD_COORDINATE\x10\x00\x12\x15\n\x11SCREEN_COORDINATE\x10\x01\x42\n\n\x08\x43ontents\x1a\x90\x01\n\x04Mesh\x12\x1f\n\x06points\x18\x01 \x03(\x0b\x32\x0f.Server.VecXYZf\x12\x16\n\x0evertex_a_index\x18\x02 \x03(\x05\x12\x16\n\x0evertex_b_index\x18\x03 \x03(\x05\x12\x16\n\x0evertex_c_index\x18\x04 \x03(\x05\x12\x1f\n\x06\x63olors\x18\x05 \x03(\x0b\x32\x0f.Server.VecRGBf\x1a\x9a\x01\n\x05Image\x12\x13\n\x0b\x64ouble_side\x18\x01 \x01(\x08\x12#\n\nupper_left\x18\x02 \x01(\x0b\x32\x0f.Server.VecXYZf\x12#\n\nlower_left\x18\x03 \x01(\x0b\x32\x0f.Server.VecXYZf\x12$\n\x0blower_right\x18\x04 \x01(\x0b\x32\x0f.Server.VecXYZf\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x42\x08\n\x06Object\":\n\x0cRemoveObject\x12\r\n\x03\x61ll\x18\x01 \x01(\x08H\x00\x12\x11\n\x07\x62y_uuid\x18\x02 \x01(\tH\x00\x42\x08\n\x06Object\"U\n\x12SetKeyEventHandler\x12\x11\n\x07keydown\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05keyup\x18\x02 \x01(\x08H\x00\x12\x12\n\x08keypress\x18\x03 \x01(\x08H\x00\x42\x07\n\x05\x45vent\"s\n\x1aSetCameraStateEventHandler\x12\x1b\n\x11\x61\x64\x64_with_interval\x18\x01 \x01(\x02H\x00\x12\x18\n\x0eremove_by_uuid\x18\x02 \x01(\tH\x00\x12\x14\n\nremove_all\x18\x03 \x01(\x08H\x00\x42\x08\n\x06\x41\x63tion\"*\n\x07VecXYZf\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"*\n\x07VecRGBf\x12\t\n\x01r\x18\x01 \x01(\x02\x12\t\n\x01g\x18\x02 \x01(\x02\x12\t\n\x01\x62\x18\x03 \x01(\x02\"\xdb\x06\n\x10SetCustomControl\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x31\n\x06slider\x18\x02 \x01(\x0b\x32\x1f.Server.SetCustomControl.SliderH\x00\x12\x35\n\x08\x63heckbox\x18\x03 \x01(\x0b\x32!.Server.SetCustomControl.CheckBoxH\x00\x12\x33\n\x07textbox\x18\x04 \x01(\x0b\x32 .Server.SetCustomControl.TextBoxH\x00\x12\x37\n\tselectbox\x18\x05 \x01(\x0b\x32\".Server.SetCustomControl.SelectBoxH\x00\x12\x31\n\x06\x62utton\x18\x06 \x01(\x0b\x32\x1f.Server.SetCustomControl.ButtonH\x00\x12<\n\x0c\x63olor_picker\x18\x07 \x01(\x0b\x32$.Server.SetCustomControl.ColorPickerH\x00\x1a\x92\x01\n\x06Slider\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03min\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x10\n\x03max\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x12\n\x05value\x18\x05 \x01(\x02H\x04\x88\x01\x01\x42\x07\n\x05_nameB\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_stepB\x08\n\x06_value\x1a\x44\n\x08\x43heckBox\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\x1a\x43\n\x07TextBox\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\x1aT\n\tSelectBox\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\r\n\x05items\x18\x02 \x03(\t\x12\x12\n\x05value\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\x1a$\n\x06\x42utton\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\x1aG\n\x0b\x43olorPicker\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_valueB\t\n\x07\x43ontrolb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf.server_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SERVERCOMMAND']._serialized_start=34
  _globals['_SERVERCOMMAND']._serialized_end=612
  _globals['_CUSTOMCONTROL']._serialized_start=615
  _globals['_CUSTOMCONTROL']._serialized_end=1446
  _globals['_CUSTOMCONTROL_SLIDER']._serialized_start=991
  _globals['_CUSTOMCONTROL_SLIDER']._serialized_end=1089
  _globals['_CUSTOMCONTROL_CHECKBOX']._serialized_start=1091
  _globals['_CUSTOMCONTROL_CHECKBOX']._serialized_end=1151
  _globals['_CUSTOMCONTROL_TEXTBOX']._serialized_start=1153
  _globals['_CUSTOMCONTROL_TEXTBOX']._serialized_end=1212
  _globals['_CUSTOMCONTROL_SELECTBOX']._serialized_start=1214
  _globals['_CUSTOMCONTROL_SELECTBOX']._serialized_end=1290
  _globals['_CUSTOMCONTROL_BUTTON']._serialized_start=1292
  _globals['_CUSTOMCONTROL_BUTTON']._serialized_end=1330
  _globals['_CUSTOMCONTROL_COLORPICKER']._serialized_start=1332
  _globals['_CUSTOMCONTROL_COLORPICKER']._serialized_end=1395
  _globals['_CUSTOMCONTROL_FOLDER']._serialized_start=1397
  _globals['_CUSTOMCONTROL_FOLDER']._serialized_end=1435
  _globals['_REMOVECUSTOMCONTROL']._serialized_start=1448
  _globals['_REMOVECUSTOMCONTROL']._serialized_end=1513
  _globals['_SETCAMERA']._serialized_start=1516
  _globals['_SETCAMERA']._serialized_end=1883
  _globals['_SETCAMERA_ROLL']._serialized_start=1774
  _globals['_SETCAMERA_ROLL']._serialized_end=1824
  _globals['_SETCAMERA_CAMERAMODE']._serialized_start=1826
  _globals['_SETCAMERA_CAMERAMODE']._serialized_end=1873
  _globals['_ADDOBJECT']._serialized_start=1886
  _globals['_ADDOBJECT']._serialized_end=2905
  _globals['_ADDOBJECT_LINESET']._serialized_start=2128
  _globals['_ADDOBJECT_LINESET']._serialized_end=2257
  _globals['_ADDOBJECT_POINTCLOUD']._serialized_start=2259
  _globals['_ADDOBJECT_POINTCLOUD']._serialized_end=2309
  _globals['_ADDOBJECT_OVERLAY']._serialized_start=2312
  _globals['_ADDOBJECT_OVERLAY']._serialized_end=2591
  _globals['_ADDOBJECT_OVERLAY_IMAGE']._serialized_start=2480
  _globals['_ADDOBJECT_OVERLAY_IMAGE']._serialized_end=2516
  _globals['_ADDOBJECT_OVERLAY_COORDINATETYPE']._serialized_start=2518
  _globals['_ADDOBJECT_OVERLAY_COORDINATETYPE']._serialized_end=2579
  _globals['_ADDOBJECT_MESH']._serialized_start=2594
  _globals['_ADDOBJECT_MESH']._serialized_end=2738
  _globals['_ADDOBJECT_IMAGE']._serialized_start=2741
  _globals['_ADDOBJECT_IMAGE']._serialized_end=2895
  _globals['_REMOVEOBJECT']._serialized_start=2907
  _globals['_REMOVEOBJECT']._serialized_end=2965
  _globals['_SETKEYEVENTHANDLER']._serialized_start=2967
  _globals['_SETKEYEVENTHANDLER']._serialized_end=3052
  _globals['_SETCAMERASTATEEVENTHANDLER']._serialized_start=3054
  _globals['_SETCAMERASTATEEVENTHANDLER']._serialized_end=3169
  _globals['_VECXYZF']._serialized_start=3171
  _globals['_VECXYZF']._serialized_end=3213
  _globals['_VECRGBF']._serialized_start=3215
  _globals['_VECRGBF']._serialized_end=3257
  _globals['_SETCUSTOMCONTROL']._serialized_start=3260
  _globals['_SETCUSTOMCONTROL']._serialized_end=4119
  _globals['_SETCUSTOMCONTROL_SLIDER']._serialized_start=3626
  _globals['_SETCUSTOMCONTROL_SLIDER']._serialized_end=3772
  _globals['_SETCUSTOMCONTROL_CHECKBOX']._serialized_start=3774
  _globals['_SETCUSTOMCONTROL_CHECKBOX']._serialized_end=3842
  _globals['_SETCUSTOMCONTROL_TEXTBOX']._serialized_start=3844
  _globals['_SETCUSTOMCONTROL_TEXTBOX']._serialized_end=3911
  _globals['_SETCUSTOMCONTROL_SELECTBOX']._serialized_start=3913
  _globals['_SETCUSTOMCONTROL_SELECTBOX']._serialized_end=3997
  _globals['_SETCUSTOMCONTROL_BUTTON']._serialized_start=3999
  _globals['_SETCUSTOMCONTROL_BUTTON']._serialized_end=4035
  _globals['_SETCUSTOMCONTROL_COLORPICKER']._serialized_start=4037
  _globals['_SETCUSTOMCONTROL_COLORPICKER']._serialized_end=4108
# @@protoc_insertion_point(module_scope)
