# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/client.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15protobuf/client.proto\x12\x06\x43lient\"\xcf\x02\n\rClientCommand\x12\x0c\n\x04UUID\x18\x01 \x01(\t\x12\x15\n\x0blog_message\x18\x02 \x01(\tH\x00\x12 \n\x06result\x18\x03 \x01(\x0b\x32\x0e.Client.ResultH\x00\x12\x1e\n\x05image\x18\x04 \x01(\x0b\x32\r.Client.ImageH\x00\x12\x31\n\x0f\x63ontrol_changed\x18\x05 \x01(\x0b\x32\x16.Client.ControlChangedH\x00\x12\x36\n\x12key_event_occurred\x18\x06 \x01(\x0b\x32\x18.Client.KeyEventOccurredH\x00\x12+\n\x0c\x63\x61mera_state\x18\x07 \x01(\x0b\x32\x13.Client.CameraStateH\x00\x12\x34\n\x15\x63\x61meara_state_changed\x18\x08 \x01(\x0b\x32\x13.Client.CameraStateH\x00\x42\t\n\x07\x43ommand\"8\n\x06Result\x12\x11\n\x07success\x18\x01 \x01(\tH\x00\x12\x11\n\x07\x66\x61ilure\x18\x02 \x01(\tH\x00\x42\x08\n\x06Result\"\x15\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"N\n\x0e\x43ontrolChanged\x12\x10\n\x06number\x18\x01 \x01(\x01H\x00\x12\x0e\n\x04text\x18\x02 \x01(\tH\x00\x12\x11\n\x07\x62oolean\x18\x03 \x01(\x08H\x00\x42\x07\n\x05Value\"\xb7\x02\n\x10KeyEventOccurred\x12\x32\n\x05keyup\x18\x01 \x01(\x0b\x32!.Client.KeyEventOccurred.KeyEventH\x00\x12\x34\n\x07keydown\x18\x02 \x01(\x0b\x32!.Client.KeyEventOccurred.KeyEventH\x00\x12\x35\n\x08keypress\x18\x03 \x01(\x0b\x32!.Client.KeyEventOccurred.KeyEventH\x00\x1ay\n\x08KeyEvent\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x10\n\x08shiftKey\x18\x03 \x01(\x08\x12\x0e\n\x06\x61ltKey\x18\x04 \x01(\x08\x12\x0f\n\x07\x63trlKey\x18\x05 \x01(\x08\x12\x0f\n\x07metaKey\x18\x06 \x01(\x08\x12\x0e\n\x06repeat\x18\x07 \x01(\x08\x42\x07\n\x05\x45vent\"\x85\x02\n\x0b\x43\x61meraState\x12!\n\x08position\x18\x01 \x01(\x0b\x32\x0f.Client.VecXYZf\x12\x1f\n\x06target\x18\x02 \x01(\x0b\x32\x0f.Client.VecXYZf\x12\x1b\n\x02up\x18\x03 \x01(\x0b\x32\x0f.Client.VecXYZf\x12,\n\x04mode\x18\x04 \x01(\x0e\x32\x1e.Client.CameraState.CameraMode\x12\x11\n\troll_lock\x18\x05 \x01(\x08\x12\x0b\n\x03\x66ov\x18\x06 \x01(\x02\x12\x16\n\x0e\x66rustum_height\x18\x07 \x01(\x02\"/\n\nCameraMode\x12\x0f\n\x0bPERSPECTIVE\x10\x00\x12\x10\n\x0cORTHOGRAPHIC\x10\x01\"*\n\x07VecXYZf\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf.client_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CLIENTCOMMAND']._serialized_start=34
  _globals['_CLIENTCOMMAND']._serialized_end=369
  _globals['_RESULT']._serialized_start=371
  _globals['_RESULT']._serialized_end=427
  _globals['_IMAGE']._serialized_start=429
  _globals['_IMAGE']._serialized_end=450
  _globals['_CONTROLCHANGED']._serialized_start=452
  _globals['_CONTROLCHANGED']._serialized_end=530
  _globals['_KEYEVENTOCCURRED']._serialized_start=533
  _globals['_KEYEVENTOCCURRED']._serialized_end=844
  _globals['_KEYEVENTOCCURRED_KEYEVENT']._serialized_start=714
  _globals['_KEYEVENTOCCURRED_KEYEVENT']._serialized_end=835
  _globals['_CAMERASTATE']._serialized_start=847
  _globals['_CAMERASTATE']._serialized_end=1108
  _globals['_CAMERASTATE_CAMERAMODE']._serialized_start=1061
  _globals['_CAMERASTATE_CAMERAMODE']._serialized_end=1108
  _globals['_VECXYZF']._serialized_start=1110
  _globals['_VECXYZF']._serialized_end=1152
# @@protoc_insertion_point(module_scope)
