body{background-color:#000;margin:0}.dg .property-name{cursor:default;float:left;clear:left;width:40%;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.cr.function .property-name{width:100%}@keyframes spinner{0%{transform:rotate(0)}to{transform:rotate(360deg)}}.cumo-spinner{position:fixed;top:calc(50% - 20px);left:calc(50% - 20px)}.cumo-spinner circle{fill:none;stroke:#fff;stroke-width:5;stroke-linecap:round;stroke-dasharray:2.5 248.7;transform-origin:50px 50px 0;animation:spinner 1s linear infinite}
